@@ -1,6 +1,7 @@
 from typing import Any, Dict  # noqa
 
 from django.conf import settings
+from django.contrib.auth.models import AnonymousUser
 from django.contrib.contenttypes.fields import GenericRelation
 from django.core.exceptions import ImproperlyConfigured, ValidationError
 from django.db import IntegrityError, models, transaction
@@ -21,6 +22,7 @@ from openslides.poll.models import (
     CollectDefaultVotesMixin,
 )
 from openslides.utils.autoupdate import inform_changed_data
+from openslides.utils.exceptions import OpenSlidesError
 from openslides.utils.models import RESTModelMixin
 
 from .access_permissions import (
@@ -81,7 +83,7 @@ class Motion(RESTModelMixin, models.Model):
     state = models.ForeignKey(
         'State',
         related_name='+',
-        on_delete=models.SET_NULL,
+        on_delete=models.PROTECT,  # Do not let the user delete states, that are used for motions
         null=True)  # TODO: Check whether null=True is necessary.
     """
     The related state object.
@@ -157,11 +159,6 @@ class Motion(RESTModelMixin, models.Model):
     Tags to categorise motions.
     """
 
-    submitters = models.ManyToManyField(settings.AUTH_USER_MODEL, related_name='motion_submitters', blank=True)
-    """
-    Users who submit this motion.
-    """
-
     supporters = models.ManyToManyField(settings.AUTH_USER_MODEL, related_name='motion_supporters', blank=True)
     """
     Users who support this motion.
@@ -217,9 +214,13 @@ class Motion(RESTModelMixin, models.Model):
             * Else the given version is used.
 
         To create and use a new version object, you have to set it via the
-        use_version argument. You have to set the title, text and reason into
-        this version object before giving it to this save method. The properties
-        motion.title, motion.text and motion.reason will be ignored.
+        use_version argument. You have to set the title, text/amendment_paragraphs,
+        modified final version and reason into this version object before giving it
+        to this save method. The properties motion.title, motion.text,
+        motion.amendment_paragraphs, motion.modified_final_version and motion.reason will be ignored.
+
+        text and amendment_paragraphs are mutually exclusive; if both are given,
+        amendment_paragraphs takes precedence.
         """
         if not self.state:
             self.reset_state()
@@ -264,8 +265,8 @@ class Motion(RESTModelMixin, models.Model):
             return
         elif use_version is None:
             use_version = self.get_last_version()
-            # Save title, text and reason into the version object.
-            for attr in ['title', 'text', 'reason']:
+            # Save title, text, amendment paragraphs, modified final version and reason into the version object.
+            for attr in ['title', 'text', 'amendment_paragraphs', 'modified_final_version', 'reason']:
                 _attr = '_%s' % attr
                 data = getattr(self, _attr, None)
                 if data is not None:
@@ -318,7 +319,8 @@ class Motion(RESTModelMixin, models.Model):
         """
         Compare the version with the last version of the motion.
 
-        Returns True if the version data (title, text, reason) is different,
+        Returns True if the version data (title, text, amendment_paragraphs,
+        modified_final_version, reason) is different,
         else returns False.
         """
         if not self.versions.exists():
@@ -326,7 +328,7 @@ class Motion(RESTModelMixin, models.Model):
             return True
 
         last_version = self.get_last_version()
-        for attr in ['title', 'text', 'reason']:
+        for attr in ['title', 'text', 'amendment_paragraphs', 'modified_final_version', 'reason']:
             if getattr(last_version, attr) != getattr(version, attr):
                 return True
         return False
@@ -463,7 +465,59 @@ class Motion(RESTModelMixin, models.Model):
 
     text = property(get_text, set_text)
     """
-    The text of a motin.
+    The text of a motion.
+
+    Is saved in a MotionVersion object.
+    """
+
+    def get_amendment_paragraphs(self):
+        """
+        Get the paragraphs of the amendment.
+        Returns an array of entries that are either null (paragraph is not changed)
+        or a string (the new version of this paragraph).
+        """
+        try:
+            return self._amendment_paragraphs
+        except AttributeError:
+            return self.get_active_version().amendment_paragraphs
+
+    def set_amendment_paragraphs(self, text):
+        """
+        Set the paragraphs of the amendment.
+        Has to be an array of entries that are either null (paragraph is not changed)
+        or a string (the new version of this paragraph).
+        """
+        self._amendment_paragraphs = text
+
+    amendment_paragraphs = property(get_amendment_paragraphs, set_amendment_paragraphs)
+    """
+    The paragraphs of the amendment.
+
+    Is saved in a MotionVersion object.
+    """
+
+    def get_modified_final_version(self):
+        """
+        Get the modified_final_version of the motion.
+
+        Simular to get_title().
+        """
+        try:
+            return self._modified_final_version
+        except AttributeError:
+            return self.get_active_version().modified_final_version
+
+    def set_modified_final_version(self, modified_final_version):
+        """
+        Set the modified_final_version of the motion.
+
+        Simular to set_title().
+        """
+        self._modified_final_version = modified_final_version
+
+    modified_final_version = property(get_modified_final_version, set_modified_final_version)
+    """
+    The modified_final_version for the motion.
 
     Is saved in a MotionVersion object.
     """
@@ -499,8 +553,9 @@ class Motion(RESTModelMixin, models.Model):
         Return a version object, not saved in the database.
 
         The version data of the new version object is populated with the data
-        set via motion.title, motion.text, motion.reason if these data are
-        not given as keyword arguments. If the data is not set in the motion
+        set via motion.title, motion.text, motion.amendment_paragraphs,
+        motion.modified_final_version and motion.reason if these data are not
+        given as keyword arguments. If the data is not set in the motion
         attributes, it is populated with the data from the last version
         object if such object exists.
         """
@@ -513,7 +568,7 @@ class Motion(RESTModelMixin, models.Model):
             last_version = self.get_last_version()
         else:
             last_version = None
-        for attr in ['title', 'text', 'reason']:
+        for attr in ['title', 'text', 'amendment_paragraphs', 'modified_final_version', 'reason']:
             if attr in kwargs:
                 continue
             _attr = '_%s' % attr
@@ -548,7 +603,7 @@ class Motion(RESTModelMixin, models.Model):
         """
         Returns True if user is a submitter of this motion, else False.
         """
-        return user in self.submitters.all()
+        return self.submitters.filter(user=user).exists()
 
     def is_supporter(self, user):
         """
@@ -682,7 +737,7 @@ class Motion(RESTModelMixin, models.Model):
         The message should be in English and translatable,
         e. g. motion.write_log(message_list=[ugettext_noop('Message Text')])
         """
-        if person and not person.is_authenticated():
+        if person and not person.is_authenticated:
             person = None
         motion_log = MotionLog(motion=self, message_list=message_list, person=person)
         motion_log.save(skip_autoupdate=skip_autoupdate)
@@ -696,6 +751,13 @@ class Motion(RESTModelMixin, models.Model):
         """
         return config['motions_amendments_enabled'] and self.parent is not None
 
+    def is_paragraph_based_amendment(self):
+        """
+        Returns True if the motion is an amendment that stores the changes on a per-paragraph-basis
+        and is therefore eligible to be shown in diff-view.
+        """
+        return self.is_amendment() and self.amendment_paragraphs
+
     def get_amendments_deep(self):
         """
         Generator that yields all amendments of this motion including all
@@ -705,6 +767,75 @@ class Motion(RESTModelMixin, models.Model):
             yield amendment
             yield from amendment.get_amendments_deep()
 
+    def get_paragraph_based_amendments(self):
+        """
+        Returns a list of all paragraph-based amendments to this motion
+        """
+        return list(filter(lambda amend: amend.is_paragraph_based_amendment(), self.amendments.all()))
+
+
+class SubmitterManager(models.Manager):
+    """
+    Manager for Submitter model. Provides a customized add method.
+    """
+    def add(self, user, motion, skip_autoupdate=False):
+        """
+        Customized manager method to prevent anonymous users to be a
+        submitter and that someone is not twice a submitter. Cares also
+        for the initial sorting of the submitters.
+        """
+        if self.filter(user=user, motion=motion).exists():
+            raise OpenSlidesError(
+                _('{user} is already a submitter.').format(user=user))
+        if isinstance(user, AnonymousUser):
+            raise OpenSlidesError(
+                _('An anonymous user can not be a submitter.'))
+        weight = (self.filter(motion=motion).aggregate(
+            models.Max('weight'))['weight__max'] or 0)
+        submitter = self.model(user=user, motion=motion, weight=weight + 1)
+        submitter.save(force_insert=True, skip_autoupdate=skip_autoupdate)
+        return submitter
+
+
+class Submitter(RESTModelMixin, models.Model):
+    """
+    M2M Model for submitters.
+    """
+
+    objects = SubmitterManager()
+    """
+    Use custom Manager.
+    """
+
+    user = models.ForeignKey(
+        settings.AUTH_USER_MODEL,
+        on_delete=models.CASCADE)
+    """
+    ForeignKey to the user who is the submitter.
+    """
+
+    motion = models.ForeignKey(
+        Motion,
+        on_delete=models.CASCADE,
+        related_name='submitters')
+    """
+    ForeignKey to the motion.
+    """
+
+    weight = models.IntegerField(null=True)
+
+    class Meta:
+        default_permissions = ()
+
+    def __str__(self):
+        return str(self.user)
+
+    def get_root_rest_element(self):
+        """
+        Returns the motion to this instance which is the root REST element.
+        """
+        return self.motion
+
 
 class MotionVersion(RESTModelMixin, models.Model):
     """
@@ -729,6 +860,18 @@ class MotionVersion(RESTModelMixin, models.Model):
     text = models.TextField()
     """The text of a motion."""
 
+    amendment_paragraphs = JSONField(null=True)
+    """
+    If paragraph-based, diff-enabled amendment style is used, this field stores an array of strings or null values.
+    Each entry corresponds to a paragraph of the text of the original motion.
+    If the entry is null, then the paragraph remains unchanged.
+    If the entry is a string, this is the new text of the paragraph.
+    amendment_paragraphs and text are mutually exclusive.
+    """
+
+    modified_final_version = models.TextField(null=True, blank=True)
+    """A field to copy in the final version of the motion and edit it there."""
+
     reason = models.TextField(null=True, blank=True)
     """The reason for a motion."""
 
@@ -1085,7 +1228,7 @@ class State(RESTModelMixin, models.Model):
     name = models.CharField(max_length=255)
     """A string representing the state."""
 
-    action_word = models.CharField(max_length=255)
+    action_word = models.CharField(max_length=255, blank=True)
     """An alternative string to be used for a button to switch to this state."""
 
     recommendation_label = models.CharField(max_length=255, null=True)
@@ -1097,7 +1240,7 @@ class State(RESTModelMixin, models.Model):
         related_name='states')
     """A many-to-one relation to a workflow."""
 
-    next_states = models.ManyToManyField('self', symmetrical=False)
+    next_states = models.ManyToManyField('self', symmetrical=False, blank=True)
     """A many-to-many relation to all states, that can be choosen from this state."""
 
     css_class = models.CharField(max_length=255, default='primary')
@@ -1227,7 +1370,8 @@ class Workflow(RESTModelMixin, models.Model):
         State,
         on_delete=models.SET_NULL,
         related_name='+',
-        null=True)
+        null=True,
+        blank=True)
     """A one-to-one relation to a state, the starting point for the workflow."""
 
     class Meta:
