@@ -21,10 +21,27 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
         var ELEMENT_NODE = 1,
             TEXT_NODE = 3;
 
+        // Counts the number of characters in the current line, beyond singe nodes.
+        // Needs to be resetted after each line break and after entering a new block node.
         this._currentInlineOffset = null;
+
+        // The last position of a point suitable for breaking the line. null or an object with the following values:
+        // - node: the node that contains the position. Guaranteed to be a TextNode
+        // - offset: the offset of the breaking characters (like the space)
+        // Needs to be resetted after each line break and after entering a new block node.
+        this._lastInlineBreakablePoint = null;
+
+        // The line number counter
         this._currentLineNumber = null;
+
+        // Indicates that we just entered a block element and we want to add a line number without line break at the beginning.
         this._prependLineNumberToFirstText = false;
+
+        // A workaround to prevent double line numbers
         this._ignoreNextRegularLineNumber = false;
+
+        // Decides if the content of inserted nodes should count as well. This is used so we can use the algorithm on a
+        // text with inline diff annotations and get the same line numbering as with the original text (when set to false)
         this._ignoreInsertedText = false;
 
         var lineNumberCache = $cacheFactory('linenumbering.service');
@@ -58,7 +75,7 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
 
         this._isOsLineBreakNode = function (node) {
             var isLineBreak = false;
-            if (node && node.nodeType === ELEMENT_NODE && node.nodeName == 'BR' && node.hasAttribute('class')) {
+            if (node && node.nodeType === ELEMENT_NODE && node.nodeName === 'BR' && node.hasAttribute('class')) {
                 var classes = node.getAttribute('class').split(' ');
                 if (classes.indexOf('os-line-break') > -1) {
                     isLineBreak = true;
@@ -69,7 +86,7 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
 
         this._isOsLineNumberNode = function (node) {
             var isLineNumber = false;
-            if (node && node.nodeType === ELEMENT_NODE && node.nodeName == 'SPAN' && node.hasAttribute('class')) {
+            if (node && node.nodeType === ELEMENT_NODE && node.nodeName === 'SPAN' && node.hasAttribute('class')) {
                 var classes = node.getAttribute('class').split(' ');
                 if (classes.indexOf('os-line-number') > -1) {
                     isLineNumber = true;
@@ -141,7 +158,6 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
                 currLineStart = 0,
                 i = 0,
                 firstTextNode = true,
-                lastBreakableIndex = null,
                 service = this;
             var addLine = function (text, highlight) {
                 var node;
@@ -171,9 +187,22 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
                     }
                 }
                 out.push(node);
+                return node;
+            };
+            var addLinebreakToPreviousNode = function (node, offset) {
+                var firstText = node.nodeValue.substr(0, offset + 1),
+                    secondText = node.nodeValue.substr(offset + 1);
+                var lineBreak = service._createLineBreak();
+                var firstNode = document.createTextNode(firstText);
+                node.parentNode.insertBefore(firstNode, node);
+                node.parentNode.insertBefore(lineBreak, node);
+                if (service._currentLineNumber !== null) {
+                    node.parentNode.insertBefore(service._createLineNumber(), node);
+                }
+                node.nodeValue = secondText;
             };
 
-            if (node.nodeValue == "\n") {
+            if (node.nodeValue === "\n") {
                 out.push(node);
             } else {
 
@@ -184,6 +213,7 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
                         out.push(service._createLineNumber());
                     }
                     this._currentInlineOffset = 0;
+                    this._lastInlineBreakablePoint = null;
                 } else if (this._prependLineNumberToFirstText) {
                     if (this._ignoreNextRegularLineNumber) {
                         this._ignoreNextRegularLineNumber = false;
@@ -196,30 +226,50 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
                 while (i < node.nodeValue.length) {
                     var lineBreakAt = null;
                     if (this._currentInlineOffset >= length) {
-                        if (lastBreakableIndex !== null) {
-                            lineBreakAt = lastBreakableIndex;
+                        if (this._lastInlineBreakablePoint !== null) {
+                            lineBreakAt = this._lastInlineBreakablePoint;
                         } else {
-                            lineBreakAt = i - 1;
+                            lineBreakAt = {
+                                'node': node,
+                                'offset': i - 1
+                            };
                         }
                     }
-                    if (lineBreakAt !== null && node.nodeValue[i] != ' ') {
-                        var currLine = node.nodeValue.substring(currLineStart, lineBreakAt + 1);
-                        addLine(currLine, highlight);
+                    if (lineBreakAt !== null && (node.nodeValue[i] !== ' ' && node.nodeValue[i] !== "\n")) {
+                        if (lineBreakAt.node === node) {
+                            // The last possible breaking point is in this text node
+                            var currLine = node.nodeValue.substring(currLineStart, lineBreakAt.offset + 1);
+                            addLine(currLine, highlight);
+
+                            currLineStart = lineBreakAt.offset + 1;
+                            this._currentInlineOffset = i - lineBreakAt.offset - 1;
+                            this._lastInlineBreakablePoint = null;
+                        } else {
+                            // The last possible breaking point was not in this text not, but one we have already passed
+                            var remainderOfPrev = lineBreakAt.node.nodeValue.length - lineBreakAt.offset - 1;
+                            addLinebreakToPreviousNode(lineBreakAt.node, lineBreakAt.offset);
+
+                            this._currentInlineOffset = i + remainderOfPrev;
+                            this._lastInlineBreakablePoint = null;
+                        }
 
-                        currLineStart = lineBreakAt + 1;
-                        this._currentInlineOffset = i - lineBreakAt - 1;
-                        lastBreakableIndex = null;
                     }
 
-                    if (node.nodeValue[i] == ' ' || node.nodeValue[i] == '-') {
-                        lastBreakableIndex = i;
+                    if (node.nodeValue[i] === ' ' || node.nodeValue[i] === '-' || node.nodeValue[i] === "\n") {
+                        this._lastInlineBreakablePoint = {
+                            'node': node,
+                            'offset': i
+                        };
                     }
 
                     this._currentInlineOffset++;
                     i++;
 
                 }
-                addLine(node.nodeValue.substring(currLineStart), highlight);
+                var lastLine = addLine(node.nodeValue.substring(currLineStart), highlight);
+                if (this._lastInlineBreakablePoint !== null) {
+                    this._lastInlineBreakablePoint.node = lastLine;
+                }
             }
             return out;
         };
@@ -251,7 +301,7 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
             if (!node.firstChild) {
                 return 0;
             }
-            if (node.firstChild.nodeType == TEXT_NODE) {
+            if (node.firstChild.nodeType === TEXT_NODE) {
                 var parts = node.firstChild.nodeValue.split(' ');
                 return parts[0].length;
             } else {
@@ -270,16 +320,17 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
             }
 
             for (i = 0; i < oldChildren.length; i++) {
-                if (oldChildren[i].nodeType == TEXT_NODE) {
+                if (oldChildren[i].nodeType === TEXT_NODE) {
                     var ret = this._textNodeToLines(oldChildren[i], length, highlight);
                     for (var j = 0; j < ret.length; j++) {
                         node.appendChild(ret[j]);
                     }
-                } else if (oldChildren[i].nodeType == ELEMENT_NODE) {
+                } else if (oldChildren[i].nodeType === ELEMENT_NODE) {
                     var firstword = this._lengthOfFirstInlineWord(oldChildren[i]),
                         overlength = ((this._currentInlineOffset + firstword) > length && this._currentInlineOffset > 0);
                     if (overlength && this._isInlineElement(oldChildren[i])) {
                         this._currentInlineOffset = 0;
+                        this._lastInlineBreakablePoint = null;
                         node.appendChild(this._createLineBreak());
                         if (this._currentLineNumber !== null) {
                             node.appendChild(this._createLineNumber());
@@ -324,13 +375,13 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
                     }
                     break;
                 case 'H1':
-                    newLength *= 0.5;
+                    newLength *= 0.66;
                     break;
                 case 'H2':
-                    newLength *= 0.66;
+                    newLength *= 0.75;
                     break;
                 case 'H3':
-                    newLength *= 0.66;
+                    newLength *= 0.85;
                     break;
             }
             return Math.ceil(newLength);
@@ -338,6 +389,7 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
 
         this._insertLineNumbersToBlockNode = function (node, length, highlight) {
             this._currentInlineOffset = 0;
+            this._lastInlineBreakablePoint = null;
             this._prependLineNumberToFirstText = true;
 
             var oldChildren = [], i;
@@ -350,7 +402,7 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
             }
 
             for (i = 0; i < oldChildren.length; i++) {
-                if (oldChildren[i].nodeType == TEXT_NODE) {
+                if (oldChildren[i].nodeType === TEXT_NODE) {
                     if (!oldChildren[i].nodeValue.match(/\S/)) {
                         // White space nodes between block elements should be ignored
                         var prevIsBlock = (i > 0 && !this._isInlineElement(oldChildren[i - 1]));
@@ -364,11 +416,12 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
                     for (var j = 0; j < ret.length; j++) {
                         node.appendChild(ret[j]);
                     }
-                } else if (oldChildren[i].nodeType == ELEMENT_NODE) {
+                } else if (oldChildren[i].nodeType === ELEMENT_NODE) {
                     var firstword = this._lengthOfFirstInlineWord(oldChildren[i]),
                         overlength = ((this._currentInlineOffset + firstword) > length && this._currentInlineOffset > 0);
                     if (overlength && this._isInlineElement(oldChildren[i]) && !this._isIgnoredByLineNumbering(oldChildren[i])) {
                         this._currentInlineOffset = 0;
+                        this._lastInlineBreakablePoint = null;
                         node.appendChild(this._createLineBreak());
                         if (this._currentLineNumber !== null) {
                             node.appendChild(this._createLineNumber());
@@ -383,6 +436,7 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
             }
 
             this._currentInlineOffset = 0;
+            this._lastInlineBreakablePoint = null;
             this._prependLineNumberToFirstText = true;
             this._ignoreNextRegularLineNumber = false;
 
@@ -413,6 +467,12 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
         this._stripLineNumbers = function (node) {
             for (var i = 0; i < node.childNodes.length; i++) {
                 if (this._isOsLineBreakNode(node.childNodes[i]) || this._isOsLineNumberNode(node.childNodes[i])) {
+                    // If a newline character follows a line break, it's been very likely inserted by the WYSIWYG-editor
+                    if (node.childNodes.length > (i + 1) && node.childNodes[i + 1].nodeType === TEXT_NODE) {
+                        if (node.childNodes[i + 1].nodeValue[0] === "\n") {
+                            node.childNodes[i + 1].nodeValue = " " + node.childNodes[i + 1].nodeValue.substring(1);
+                        }
+                    }
                     node.removeChild(node.childNodes[i]);
                     i--;
                 } else {
@@ -434,15 +494,21 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
         /**
          *
          * @param {string} html
-         * @param {number} lineLength
+         * @param {number|string} lineLength
          * @param {number|null} highlight - optional
          * @param {number|null} firstLine
          */
         this.insertLineNumbersNode = function (html, lineLength, highlight, firstLine) {
+            // Removing newlines after BRs, as they lead to problems like #3410
+            if (html) {
+                html = html.replace(/(<br[^>]*>)[\n\r]+/gi, '$1');
+            }
+
             var root = document.createElement('div');
             root.innerHTML = html;
 
             this._currentInlineOffset = 0;
+            this._lastInlineBreakablePoint = null;
             if (firstLine) {
                 this._currentLineNumber = parseInt(firstLine);
             } else {
@@ -475,7 +541,8 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
                 newRoot = this.insertLineNumbersNode(html, lineLength, highlight, firstLine);
                 newHtml = newRoot.innerHTML;
             } else {
-                var cacheKey = this.djb2hash(html);
+                var firstLineStr = (firstLine === undefined || firstLine === null ? '' : firstLine.toString());
+                var cacheKey = this.djb2hash(firstLineStr + "-" + lineLength.toString() + html);
                 newHtml = lineNumberCache.get(cacheKey);
 
                 if (angular.isUndefined(newHtml)) {
@@ -502,6 +569,7 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
             root.innerHTML = html;
 
             this._currentInlineOffset = 0;
+            this._lastInlineBreakablePoint = null;
             this._currentLineNumber = null;
             this._prependLineNumberToFirstText = true;
             this._ignoreNextRegularLineNumber = false;
@@ -523,6 +591,115 @@ angular.module('OpenSlidesApp.motions.lineNumbering', [])
             return root.innerHTML;
         };
 
+        /**
+         * @param {string} html
+         * @returns {object}
+         *          {"from": 23, "to": 42} ; "to" refers to the line breaking element at the end of the last line,
+         *                                   i.e. the line number of the following line
+         */
+        this.getLineNumberRange = function (html) {
+            var fragment = this._htmlToFragment(html),
+                range = {
+                    "from": null,
+                    "to": null
+                };
+            var lineNumbers = fragment.querySelectorAll('.os-line-number');
+            for (var i = 0; i < lineNumbers.length; i++) {
+                var node = lineNumbers.item(i);
+                var number = parseInt(node.getAttribute("data-line-number"));
+                if (range.from === null || number < range.from) {
+                    range.from = number;
+                }
+                if (range.to === null || (number + 1) > range.to) {
+                    range.to = number + 1;
+                }
+            }
+            return range;
+        };
+
+        /**
+         * @param {string} html
+         */
+        this.getHeadingsWithLineNumbers = function (html) {
+            var fragment = this._htmlToFragment(html),
+                headings = [];
+            var headingNodes = fragment.querySelectorAll('h1, h2, h3, h4, h5, h6');
+            for (var i = 0; i < headingNodes.length; i++) {
+                var heading = headingNodes.item(i);
+                var linenumbers = heading.querySelectorAll('.os-line-number');
+                if (linenumbers.length > 0) {
+                    var number = parseInt(linenumbers.item(0).getAttribute("data-line-number"));
+                    headings.push({
+                        "lineNumber": number,
+                        "level": parseInt(heading.nodeName.substr(1)),
+                        "text": heading.innerText.replace(/^\s/, "").replace(/\s$/, "")
+                    });
+                }
+            }
+            return headings.sort(function(heading1, heading2) {
+                if (heading1.lineNumber < heading2.lineNumber) {
+                    return 0;
+                } else if (heading1.lineNumber > heading2.lineNumber) {
+                    return 1;
+                } else {
+                    return 0;
+                }
+            });
+        };
+
+        /**
+         * @param {Element} node
+         * @returns {array}
+         * @private
+         */
+        this._splitNodeToParagraphs = function (node) {
+            var elements = [];
+            for (var i = 0; i < node.childNodes.length; i++) {
+                var childNode = node.childNodes.item(i);
+
+                if (childNode.nodeType === TEXT_NODE) {
+                    continue;
+                }
+                if (childNode.nodeName === 'UL' || childNode.nodeName === 'OL') {
+                    var start = 1;
+                    if (childNode.getAttribute("start") !== null) {
+                        start = parseInt(childNode.getAttribute("start"));
+                    }
+                    for (var j = 0; j < childNode.childNodes.length; j++) {
+                        if (childNode.childNodes.item(j).nodeType === TEXT_NODE) {
+                            continue;
+                        }
+                        var newParent = childNode.cloneNode(false);
+                        if (childNode.nodeName === 'OL') {
+                            newParent.setAttribute('start', start);
+                        }
+                        newParent.appendChild(childNode.childNodes.item(j).cloneNode(true));
+                        elements.push(newParent);
+                        start++;
+                    }
+                } else {
+                    elements.push(childNode);
+                }
+            }
+            return elements;
+        };
+
+        /**
+         * Splitting the text into paragraphs:
+         * - Each root-level-element is considered as a paragraph.
+         *   Inline-elements at root-level are not expected and treated as block elements.
+         *   Text-nodes at root-level are not expected and ignored. Every text needs to be wrapped e.g. by <p> or <div>.
+         * - If a UL or OL is encountered, paragraphs are defined by the child-LI-elements.
+         *   List items of nested lists are not considered as a paragraph of their own.
+         *
+         * @param {string} html
+         * @return {string[]}
+         */
+        this.splitToParagraphs = function (html) {
+            var fragment = this._htmlToFragment(html);
+            return this._splitNodeToParagraphs(fragment).map(function(node) { return node.outerHTML; });
+        };
+
         /**
          * Traverses up the DOM tree until it finds a node with a nextSibling, then returns that sibling
          *
