@@ -53,7 +53,8 @@ angular.module('OpenSlidesApp.motions.motionBlock', [])
     'gettextCatalog',
     'Agenda',
     'AgendaTree',
-    function ($http, operator, gettextCatalog, Agenda, AgendaTree) {
+    'ShowAsAgendaItemField',
+    function ($http, operator, gettextCatalog, Agenda, AgendaTree, ShowAsAgendaItemField) {
         return {
             // Get ngDialog configuration.
             getDialog: function (motionBlock) {
@@ -69,8 +70,8 @@ angular.module('OpenSlidesApp.motions.motionBlock', [])
                 };
             },
             // Get angular-formly fields.
-            getFormFields: function () {
-                return [
+            getFormFields: function (isCreateForm) {
+                var formFields = [
                     {
                         key: 'title',
                         type: 'input',
@@ -78,26 +79,25 @@ angular.module('OpenSlidesApp.motions.motionBlock', [])
                             label: gettextCatalog.getString('Title')
                         }
                     },
-                    {
-                        key: 'showAsAgendaItem',
-                        type: 'checkbox',
-                        templateOptions: {
-                            label: gettextCatalog.getString('Show as agenda item'),
-                            description: gettextCatalog.getString('If deactivated it appears as internal item on agenda.')
-                        },
-                        hide: !(operator.hasPerms('motions.can_manage') && operator.hasPerms('agenda.can_manage'))
-                    },
-                    {
-                        key: 'agenda_parent_item_id',
+                ];
+
+                // show as agenda item + parent item
+                if (isCreateForm) {
+                    formFields.push(ShowAsAgendaItemField('motions.can_manage'));
+                    formFields.push({
+                        key: 'agenda_parent_id',
                         type: 'select-single',
                         templateOptions: {
                             label: gettextCatalog.getString('Parent item'),
                             options: AgendaTree.getFlatTree(Agenda.getAll()),
                             ngOptions: 'item.id as item.getListViewTitle() for item in to.options | notself : model.agenda_item_id',
                             placeholder: gettextCatalog.getString('Select a parent item ...')
-                        }
-                    }
-                ];
+                        },
+                        hide: !operator.hasPerms('agenda.can_manage')
+                    });
+                }
+
+                return formFields;
             }
         };
     }
@@ -144,9 +144,18 @@ angular.module('OpenSlidesApp.motions.motionBlock', [])
     'motionBlockId',
     'Projector',
     'ProjectionDefault',
+    'WebpageTitle',
+    'gettextCatalog',
     'ErrorMessage',
-    function($scope, $http, ngDialog, Motion, MotionBlockForm, MotionBlock, motionBlockId, Projector, ProjectionDefault, ErrorMessage) {
-        MotionBlock.bindOne(motionBlockId, $scope, 'motionBlock');
+    function($scope, $http, ngDialog, Motion, MotionBlockForm, MotionBlock, motionBlockId, Projector,
+        ProjectionDefault, WebpageTitle, gettextCatalog, ErrorMessage) {
+        $scope.$watch(function () {
+            return MotionBlock.lastModified(motionBlockId);
+        }, function () {
+            $scope.motionBlock = MotionBlock.get(motionBlockId);
+            WebpageTitle.updateTitle(gettextCatalog.getString('Motion block') + ' ' +
+                $scope.motionBlock.agenda_item.getTitle());
+        });
         Motion.bindAll({}, $scope, 'motions');
         $scope.$watch(function () {
             return Projector.lastModified();
@@ -181,24 +190,20 @@ angular.module('OpenSlidesApp.motions.motionBlock', [])
     '$scope',
     'MotionBlock',
     'MotionBlockForm',
-    'AgendaUpdate',
-    function($scope, MotionBlock, MotionBlockForm, AgendaUpdate) {
+    'Config',
+    function($scope, MotionBlock, MotionBlockForm, Config) {
         // Prepare form.
-        $scope.model = {};
-        $scope.model.showAsAgendaItem = true;
+        $scope.model = {
+            agenda_type: parseInt(Config.get('agenda_new_items_default_visibility').value),
+        };
 
         // Get all form fields.
-        $scope.formFields = MotionBlockForm.getFormFields();
+        $scope.formFields = MotionBlockForm.getFormFields(true);
 
         // Save form.
         $scope.save = function (motionBlock) {
             MotionBlock.create(motionBlock).then(
                 function (success) {
-                    // type: Value 1 means a non hidden agenda item, value 2 means a hidden agenda item,
-                    // see openslides.agenda.models.Item.ITEM_TYPE.
-                    var changes = [{key: 'type', value: (motionBlock.showAsAgendaItem ? 1 : 2)},
-                                   {key: 'parent_id', value: motionBlock.agenda_parent_item_id}];
-                    AgendaUpdate.saveChanges(success.agenda_item_id, changes);
                     $scope.closeThisDialog();
                 },
                 function (error) {
@@ -218,11 +223,8 @@ angular.module('OpenSlidesApp.motions.motionBlock', [])
     '$state',
     'MotionBlock',
     'MotionBlockForm',
-    'AgendaUpdate',
     'motionBlockId',
-    function($scope, $state, MotionBlock, MotionBlockForm, AgendaUpdate, motionBlockId) {
-        // TODO: Check #2486 and remove some agenda related code.
-        //MotionBlock.loadRelations(motionBlock, 'agenda_item');
+    function($scope, $state, MotionBlock, MotionBlockForm, motionBlockId) {
         $scope.alert = {};
 
         // Prepare form. Set initial values by creating a deep copy of
@@ -232,23 +234,14 @@ angular.module('OpenSlidesApp.motions.motionBlock', [])
 
         // Get all form fields.
         $scope.formFields = MotionBlockForm.getFormFields();
-        for (var i = 0; i < $scope.formFields.length; i++) {
-            if ($scope.formFields[i].key == 'showAsAgendaItem') {
-                // Get state from agenda item (hidden/internal or agenda item).
-                $scope.formFields[i].defaultValue = !motionBlock.agenda_item.is_hidden;
-            } else if ($scope.formFields[i].key == 'agenda_parent_item_id') {
-                $scope.formFields[i].defaultValue = motionBlock.agenda_item.parent_id;
-            }
-        }
+
         // Save form.
         $scope.save = function (motionBlock) {
+            // inject the changed motionBlock (copy) object back into DS store
+            MotionBlock.inject(motionBlock);
+            // save changed motionBlock object on server
             MotionBlock.create(motionBlock).then(
                 function (success) {
-                    // type: Value 1 means a non hidden agenda item, value 2 means a hidden agenda item,
-                    // see openslides.agenda.models.Item.ITEM_TYPE.
-                    var changes = [{key: 'type', value: (motionBlock.showAsAgendaItem ? 1 : 2)},
-                                   {key: 'parent_id', value: motionBlock.agenda_parent_item_id}];
-                    AgendaUpdate.saveChanges(success.agenda_item_id,changes);
                     $scope.closeThisDialog();
                 },
                 function (error) {
