@@ -6,6 +6,7 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
 
 .factory('MotionContentProvider', [
     '$q',
+    '$filter',
     'operator',
     'gettextCatalog',
     'PDFLayout',
@@ -16,9 +17,10 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
     'Config',
     'Motion',
     'MotionComment',
+    'MotionPollDecimalPlaces',
     'OpenSlidesSettings',
-    function($q, operator, gettextCatalog, PDFLayout, PdfMakeConverter, ImageConverter,
-        HTMLValidizer, Category, Config, Motion, MotionComment, OpenSlidesSettings) {
+    function($q, $filter, operator, gettextCatalog, PDFLayout, PdfMakeConverter, ImageConverter,
+        HTMLValidizer, Category, Config, Motion, MotionComment, MotionPollDecimalPlaces, OpenSlidesSettings) {
         /**
          * Provides the content as JS objects for Motions in pdfMake context
          * @constructor
@@ -33,6 +35,7 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
                     text: true,
                     reason: true,
                     state: true,
+                    category: true,
                     submitters: true,
                     votingresult: true,
                     motionBlock: true,
@@ -71,7 +74,7 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
             if (motion.parent_id) {
                 var parentMotion = Motion.get(motion.parent_id);
                 subtitleLines.push(
-                    gettextCatalog.getString('Amendment of motion') + ': ' +
+                    gettextCatalog.getString('Amendment to motion') + ': ' +
                     (parentMotion.identifier ? parentMotion.identifier : parentMotion.getTitle())
                 );
             }
@@ -86,9 +89,11 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
                 var metaTableBody = [];
 
                 // submitters
-                var submitters = _.map(motion.submitters, function (submitter) {
-                    return submitter.get_full_name();
-                }).join(', ');
+                var submitters = _.map(
+                    $filter('orderBy')(motion.submitters, 'weight'), function (submitter) {
+                        return submitter.user.get_full_name();
+                    }
+                ).join(', ');
                 if (params.include.submitters) {
                     metaTableBody.push([
                         {
@@ -131,7 +136,7 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
                 }
 
                 // category
-                if (motion.category) {
+                if (params.include.category && motion.category) {
                     metaTableBody.push([
                         {
                             text: gettextCatalog.getString('Category') + ':',
@@ -182,40 +187,41 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
                                 column2.push('');
                                 column3.push('');
                             }
+                            var precision = MotionPollDecimalPlaces.getPlaces(poll);
                             // yes
                             var yes = poll.getVote(poll.yes, 'yes');
                             column1.push(gettextCatalog.getString('Yes') + ':');
-                            column2.push(yes.value);
+                            column2.push($filter('number')(yes.value, precision));
                             column3.push(yes.percentStr);
                             // no
                             var no = poll.getVote(poll.no, 'no');
                             column1.push(gettextCatalog.getString('No') + ':');
-                            column2.push(no.value);
+                            column2.push($filter('number')(no.value, precision));
                             column3.push(no.percentStr);
                             // abstain
                             var abstain = poll.getVote(poll.abstain, 'abstain');
                             column1.push(gettextCatalog.getString('Abstain') + ':');
-                            column2.push(abstain.value);
+                            column2.push($filter('number')(abstain.value, precision));
                             column3.push(abstain.percentStr);
                             // votes valid
                             if (poll.votesvalid) {
                                 var valid = poll.getVote(poll.votesvalid, 'votesvalid');
                                 column1.push(gettextCatalog.getString('Valid votes') + ':');
-                                column2.push(valid.value);
+                                column2.push($filter('number')(valid.value, precision));
                                 column3.push(valid.percentStr);
                             }
                             // votes invalid
                             if (poll.votesvalid) {
                                 var invalid = poll.getVote(poll.votesinvalid, 'votesinvalid');
                                 column1.push(gettextCatalog.getString('Invalid votes') + ':');
-                                column2.push(invalid.value);
+                                column2.push($filter('number')(invalid.value, precision));
                                 column3.push(invalid.percentStr);
                             }
                             // votes cast
                             if (poll.votescast) {
                                 var cast = poll.getVote(poll.votescast, 'votescast');
                                 column1.push(gettextCatalog.getString('Votes cast') + ':');
-                                column2.push(cast.value);
+                                column2.push($filter('number')(cast.value, precision));
                                 column3.push(cast.percentStr);
                             }
                         }
@@ -249,7 +255,7 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
                 }
 
                 // summary of change recommendations (for motion diff version only)
-                if (params.changeRecommendationMode === "diff" && motion.changeRecommendations.length) {
+                if (params.changeRecommendationMode === 'diff' && motion.changeRecommendations.length) {
                     var columnLineNumbers = [];
                     var columnChangeType = [];
                     angular.forEach(_.orderBy(motion.changeRecommendations, ['line_from']), function(change) {
@@ -316,6 +322,7 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
                         margin: [0, 0, 0, 20],
                         layout: '{{motion-placeholder-to-insert-functions-here}}'
                     };
+                    params.include.metatable = true;
                     return metaTable;
                 } else {
                     return {};
@@ -324,40 +331,57 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
 
             // motion title
             var motionTitle = function() {
-                if (params.include.text) {
+                if (params.include.metatable && params.include.text && !motion.isParagraphBasedAmendment()) {
                     return [{
                         text: titlePlain,
                         style: 'heading3'
                     }];
+                } else {
+                    return {};
                 }
             };
 
             // motion preamble
             var motionPreamble = function () {
-                if (params.include.text) {
-                    return {
-                        text: Config.translate(Config.get('motions_preamble').value),
-                        margin: [0, 10, 0, 0]
-                    };
-                }
+                return {
+                    text: Config.translate(Config.get('motions_preamble').value),
+                    margin: [0, 10, 0, 0]
+                };
             };
 
             var escapeHtml = function(text) {
-                return text.replace(/&/, "&amp;").replace(/</, "&lt;").replace(/>/, "&gt;");
+                return text.replace(/&/, '&amp;').replace(/</, '&lt;').replace(/>/, '&gt;');
             };
 
             // motion text (with line-numbers)
             var motionText = function() {
+                var content = [];
                 if (params.include.text) {
                     var motionTextContent = '';
-                    var titleChange = motion.getTitleChangeRecommendation();
-                    if (params.changeRecommendationMode === 'diff' && titleChange) {
-                        motionTextContent += '<p><strong>' + gettextCatalog.getString('New title') + ':</strong> ' +
-                            escapeHtml(titleChange.text) + '</p>';
+                    if (motion.isParagraphBasedAmendment()) {
+                        // paragraph based amendment
+                        var diffs = motion.getAmendmentParagraphsLinesDiff();
+                        if (diffs.length) {
+                            content.push(motionPreamble());
+                            _.forEach(diffs, function (diff) {
+                                motionTextContent += diff.textPre + diff.text + diff.textPost;
+                            });
+                        } else {
+                            motionTextContent += gettextCatalog.getString('No changes at the text.');
+                        }
+                    } else {
+                        // lead motion or normal amendment
+                        content.push(motionPreamble());
+                        var titleChange = motion.getTitleChangeRecommendation();
+                        if (params.changeRecommendationMode === 'diff' && titleChange) {
+                            motionTextContent += '<p><strong>' + gettextCatalog.getString('New title') + ':</strong> ' +
+                                escapeHtml(titleChange.text) + '</p>';
+                        }
+                        motionTextContent += motion.getTextByMode(params.changeRecommendationMode, motionVersion);
                     }
-                    motionTextContent += motion.getTextByMode(params.changeRecommendationMode, motionVersion);
-                    return converter.convertHTML(motionTextContent, params.lineNumberMode);
+                    content.push(converter.convertHTML(motionTextContent, params.lineNumberMode));
                 }
+                return content;
             };
 
             // motion reason heading
@@ -418,10 +442,10 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
                     title,
                     subtitle,
                     metaTable(),
-                    motionTitle(),
-                    motionPreamble(),
-                    motionText(),
+                    motionTitle()
                 ];
+                content = content.concat(motionText());
+
                 var reason = motionReason();
                 if (reason) {
                     content.push(reason);
@@ -442,6 +466,10 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
                 return motion.identifier ? motion.identifier : '';
             };
 
+            var getId = function() {
+                return motion.id;
+            };
+
             var getCategory = function() {
                 return motion.category;
             };
@@ -458,6 +486,7 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
                         getContent: getContent,
                         getTitle: getTitle,
                         getIdentifier: getIdentifier,
+                        getId: getId,
                         getCategory: getCategory,
                         getImageMap: getImageMap,
                     });
@@ -512,7 +541,7 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
             if (motion.parent_id) {
                 var parentMotion = Motion.get(motion.parent_id);
                 subtitleLines.push(
-                    gettextCatalog.getString('Amendment of motion') + ': ' +
+                    gettextCatalog.getString('Amendment to motion') + ': ' +
                     (parentMotion.identifier ? parentMotion.identifier : parentMotion.getTitle())
                 );
             }
@@ -527,7 +556,7 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
 
                 // submitters
                 var submitters = _.map(motion.submitters, function (submitter) {
-                    return submitter.get_full_name();
+                    return submitter.user.get_full_name();
                 }).join(', ');
                 metaTableBody.push([
                     {
@@ -815,8 +844,9 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
         * Constructor
         * @function
         * @param {object} allMotions - A sorted array of all motions to parse
+        * @param {string} sorting - The way the catalog has been sorted. Necessary for ToC
         */
-        var createInstance = function(allMotions) {
+        var createInstance = function(allMotions, sorting) {
 
             var title = PDFLayout.createTitle(
                 Config.translate(Config.get('motions_export_title').value)
@@ -835,84 +865,130 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
             };
 
             var createTOContent = function() {
-                var heading = {
-                    text: gettextCatalog.getString("Table of contents"),
-                    style: "heading2"
+                var toc = [];
+                var exportCategory = (sorting === 'identifier' || sorting === 'category.prefix');
+                var uniqueCategories = getUniqueCategories();
+                var tocTitle = {
+                    text: gettextCatalog.getString('Table of contents'),
+                    style: 'heading2'
                 };
 
-                var toc = [];
-                angular.forEach(allMotions, function(motion) {
-                    var identifier = motion.getIdentifier() ? motion.getIdentifier() : '';
-                    toc.push(
-                        {
-                            columns: [
-                                {
-                                    text: identifier,
-                                    style: 'tableofcontent',
-                                    width: 70
-                                },
-                                {
-                                    text: motion.getTitle(),
-                                    style: 'tableofcontent'
-                                }
-                            ]
-                        }
-                    );
+                // all motions need a page ID. We use the motion identifier for that
+                _.forEach(allMotions, function (motion) {
+                    motion.getContent()[0].id = ''+motion.getId();
                 });
 
+                if (exportCategory && uniqueCategories) {
+                    // own table per category
+                    var catTocBody = [];
+                    _.forEach(uniqueCategories, function (category) {
+                        // push the name of the category
+                        // make a table for correct alignment
+                        catTocBody.push({
+                            table: {
+                                body: [
+                                    [
+                                        {
+                                            text: category.prefix + ' - ' + category.name,
+                                            style: 'tocCategoryTitle'
+                                        }
+                                    ],
+                                ]
+                            },
+                            layout: 'noBorders',
+                        });
+
+                        var tocBody = [];
+                        _.forEach(allMotions, function (motion) {
+                            if (motion.getCategory() && category.name === motion.getCategory().name) {
+                                tocBody.push(tocLine(motion, 'tocCategoryEntry'));
+                            }
+                        });
+                        catTocBody.push(tocTable(tocBody));
+                    });
+
+                    //handle thouse without category
+                    var uncatTocBody = [];
+                    _.forEach(allMotions, function (motion) {
+                        if (!motion.getCategory()) {
+                            uncatTocBody.push(tocLine(motion, 'tocEntry'));
+                        }
+                    });
+
+                    // only push this array if there is at least one entry
+                    if (uncatTocBody.length > 0) {
+                        catTocBody.push(tocTable(uncatTocBody));
+                    }
+
+                    toc.push(catTocBody);
+                } else {
+                    // all categories in the same table
+                    var tocBody = [];
+                    _.forEach(allMotions, function (motion) {
+                        tocBody.push(tocLine(motion, 'tocEntry'));
+                    });
+                    toc.push(tocTable(tocBody));
+                }
+
                 return [
-                    heading,
+                    tocTitle,
                     toc,
                     PDFLayout.addPageBreak()
                 ];
             };
 
-            // function to create the table of catergories (if any)
-            var createTOCategories = function() {
+            // creates a new table of contents table body
+            var tocTable = function (tocBody) {
+                return {
+                    table: {
+                        widths: ['auto', '*', 'auto'],
+                        body: tocBody
+                    },
+                    layout: 'noBorders',
+                    style: 'tocCategorySection'
+                };
+            };
+
+            // generates a line in the toc as list-object
+            var tocLine = function (motion, style) {
+                var firstColumn = "";
+                if (motion.getIdentifier()) {
+                    firstColumn = motion.getIdentifier();
+                }
+                return [
+                    {
+                        text: firstColumn,
+                        style: style
+                    },
+                    {
+                        text: motion.getTitle(),
+                        style: 'tocEntry'
+                    },
+                    {
+                        pageReference: ''+motion.getId(),
+                        style: 'tocEntry',
+                        alignment: 'right'
+                    },
+                ];
+            };
+
+            // returns a list of unique category names
+            // necessary to create a ToC with categories
+            // if a motions without category is found,
+            // a corresponding entry should be added aswell
+            var getUniqueCategories = function() {
                 var categories = [];
                 _.forEach(allMotions, function (motion) {
-                    var category = motion.getCategory();
-                    if (category) {
-                        categories.push(category);
-                    }
-                });
-                var sortKey = Config.get('motions_export_category_sorting').value;
-                categories = _.orderBy(_.uniqBy(categories, 'id'), [sortKey]);
-                if (categories.length > 1) {
-                    var heading = {
-                        text: gettextCatalog.getString('Categories'),
-                        style: 'heading2',
-                    };
-
-                    var toc = [];
-                    angular.forEach(categories, function(cat) {
-                        toc.push(
+                    if (motion.getCategory()) {
+                        categories.push(
                             {
-                                columns: [
-                                    {
-                                        text: cat.prefix,
-                                        style: 'tableofcontent',
-                                        width: 50
-                                    },
-                                    {
-                                        text: cat.name,
-                                        style: 'tableofcontent'
-                                    }
-                                ]
+                                name: motion.getCategory().name,
+                                prefix: motion.getCategory().prefix
                             }
                         );
-                    });
-
-                    return [
-                        heading,
-                        toc,
-                        PDFLayout.addPageBreak()
-                    ];
-                } else {
-                    // if there are no categories, return "empty string"
-                    // pdfmake takes "null" literally and throws an error
-                    return "";
-                }
+                    }
+                });
+                return _.uniqBy(categories, 'name');
             };
 
             // returns the pure content of the motion, parseable by pdfmake
@@ -930,7 +1006,6 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
                     content.push(
                         title,
                         createPreamble(),
-                        createTOCategories(),
                         createTOContent()
                     );
                 }
@@ -962,6 +1037,210 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
     }
 ])
 
+.factory('AmendmentContentProvider', [
+    '$q',
+    'ImageConverter',
+    'PdfMakeConverter',
+    'HTMLValidizer',
+    'PDFLayout',
+    'Config',
+    'gettextCatalog',
+    function ($q, ImageConverter, PdfMakeConverter, HTMLValidizer, PDFLayout, Config, gettextCatalog) {
+        var createInstance = function (motions) {
+            motions = _.filter(motions, function (motion) {
+                return motion.parent_id;
+            });
+
+            var converter, imageMap = {};
+
+            // Query all image sources from motion text and reason
+            var getImageSources = function () {
+                var sources = [];
+                _.forEach(motions, function (motion) {
+                    var text = motion.getText();
+                    var reason = motion.getReason();
+                    var content = HTMLValidizer.validize(text) + HTMLValidizer.validize(motion.getReason());
+                    _.forEach($(content).find('img'), function (element) {
+                        sources.push(element.getAttribute('src'));
+                    });
+                });
+                return _.uniq(sources);
+            };
+
+            var createBundleContent = function (bundle) {
+                return _.flatten(_.map(bundle, function (motion) {
+                    var content = [];
+
+                    // get diffs and title of the changed motions
+                    var motionText;
+                    var title = motion.identifier ? gettextCatalog.getString('Motion') + ' ' + motion.identifier : motion.getTitle();
+                    if (motion.isParagraphBasedAmendment()) {
+                        // get changed parts
+                        var paragraphs = motion.getAmendmentParagraphsLinesDiff();
+                        if (paragraphs.length) {
+                            // Put the changed lines into the info column
+                            var p = paragraphs[0];
+                            title += ' (' + gettextCatalog.getString('Line') + ' ';
+                            if (p.diffLineTo === p.diffLineFrom + 1) {
+                                title += p.diffLineFrom;
+                            } else {
+                                title += p.diffLineFrom + '-' + p.diffLineTo;
+                            }
+                            title += ')';
+
+                            // get the diff
+                            motionText = p.text;
+                        } else {
+                            motionText = gettextCatalog.getString('No changes at the text.');
+                        }
+                    } else { // 'normal' amendment
+                        motionText = motion.getText();
+                    }
+                    content.push({
+                        text: title,
+                        style: 'heading3',
+                        marginTop: 15,
+                    });
+
+                    // submitters
+                    var submitters = _.map(motion.submitters, function (submitter) {
+                        return submitter.user.get_full_name();
+                    }).join(', ');
+                    content.push({
+                        text: gettextCatalog.getString('Submitters') + ': ' + submitters,
+                    });
+
+                    // state
+                    content.push({
+                        text: gettextCatalog.getString('State') + ': ' + motion.getStateName(),
+                    });
+
+                    // recommendation
+                    var recommendations_by = Config.get('motions_recommendations_by').value;
+                    var recommendation = motion.getRecommendationName();
+                    if (recommendations_by && recommendation) {
+                        content.push({
+                            text: recommendations_by + ': ' + recommendation,
+                        });
+                    }
+
+                    return _.concat(content, converter.convertHTML(motionText, 'outside'));
+                }));
+            };
+
+            var getBundleContent = function (bundle) {
+                var leadMotion = bundle[0].getParentMotion();
+                // title
+                var title = leadMotion.identifier ? ' ' + leadMotion.identifier : '';
+                title += ': ' + leadMotion.getTitle();
+                title = PDFLayout.createTitle(gettextCatalog.getString('Amendments to motion') + title);
+
+                var content = [title],
+                    foundAmendments = [];
+
+                var headings = leadMotion.getTextHeadings().map(function(heading) {
+                    heading.amendments = [];
+                    return heading;
+                });
+                bundle.forEach(function(amendment) {
+                    var headingIdx = null;
+                    var changes = amendment.getAmendmentParagraphsByMode('diff');
+                    if (changes.length === 0) {
+                        return;
+                    }
+                    var amendmentLineNumber = changes[0].lineFrom;
+                    for (var i = 0; i < headings.length; i++) {
+                        if (headings[i].lineNumber <= amendmentLineNumber) {
+                            headingIdx = i;
+                        }
+                    }
+                    if (headingIdx !== null) {
+                        headings[headingIdx].amendments.push(amendment);
+                        foundAmendments.push(amendment.id);
+                    }
+                });
+
+                headings.forEach(function(heading) {
+                    if (heading.amendments.length === 0) {
+                        return;
+                    }
+                    content.push({
+                        text: heading.text,
+                        style: "heading2",
+                        marginTop: 25,
+                    });
+                    content = _.concat(content, createBundleContent(heading.amendments));
+                });
+
+                // If there was an amendment that did not have a heading, we append it at the bottom
+                var missedAmendments = [];
+                bundle.forEach(function(amendment) {
+                    if (foundAmendments.indexOf(amendment.id) === -1) {
+                        missedAmendments.push(amendment);
+                    }
+                });
+                if (missedAmendments.length > 0) {
+                    content = _.concat(content, createBundleContent(missedAmendments));
+                }
+
+                return content;
+            };
+
+            // Generates content as a pdfmake consumable
+            var getContent = function() {
+                if (motions.length === 0) {
+                    return [];
+                }
+
+                // Creates bundles of motions. All motions with the same parent are bundled together
+                // respecting the order, in which they are sorted.
+                // motionBundles is an array containing Arrays of motions with the same parent.
+                var parentId = motions[0].parent_id;
+                var motionBundles = [];
+                var currentBundle = [];
+                _.forEach(motions, function (motion) {
+                    if (motion.parent_id === parentId) {
+                        currentBundle.push(motion);
+                    } else {
+                        motionBundles.push(currentBundle);
+                        currentBundle = [motion];
+                        parentId = motion.parent_id;
+                    }
+                });
+                motionBundles.push(currentBundle);
+
+                // Make the amendment table for each motion bundle.
+                return _.map(motionBundles, function (bundle, index) {
+                    var content = getBundleContent(bundle);
+                    if (index < motionBundles.length - 1) {
+                        content.push(PDFLayout.addPageBreak());
+                    }
+                    return content;
+                });
+            };
+
+            var getImageMap = function() {
+                return imageMap;
+            };
+
+            return $q(function (resolve) {
+                ImageConverter.toBase64(getImageSources()).then(function (_imageMap) {
+                    imageMap = _imageMap;
+                    converter = PdfMakeConverter.createInstance(_imageMap);
+                    resolve({
+                        getContent: getContent,
+                        getImageMap: getImageMap,
+                    });
+                });
+            });
+        };
+
+        return {
+            createInstance: createInstance,
+        };
+    }
+])
+
 .factory('MotionPdfExport', [
     '$http',
     '$q',
@@ -977,6 +1256,7 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
     'PollContentProvider',
     'PdfMakeBallotPaperProvider',
     'MotionPartialContentProvider',
+    'AmendmentContentProvider',
     'PdfCreate',
     'PDFLayout',
     'PersonalNoteManager',
@@ -985,8 +1265,8 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
     'FileSaver',
     function ($http, $q, operator, Config, gettextCatalog, MotionChangeRecommendation, HTMLValidizer,
         PdfMakeConverter, MotionContentProvider, MotionCatalogContentProvider, PdfMakeDocumentProvider,
-        PollContentProvider, PdfMakeBallotPaperProvider, MotionPartialContentProvider, PdfCreate,
-        PDFLayout, PersonalNoteManager, MotionComment, Messaging, FileSaver) {
+        PollContentProvider, PdfMakeBallotPaperProvider, MotionPartialContentProvider, AmendmentContentProvider,
+        PdfCreate, PDFLayout, PersonalNoteManager, MotionComment, Messaging, FileSaver) {
         return {
             getDocumentProvider: function (motions, params, singleMotion) {
                 params = _.clone(params || {}); // Clone this to avoid sideeffects.
@@ -1030,7 +1310,7 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
                         if (singleMotion) {
                             documentProviderPromise = PdfMakeDocumentProvider.createInstance(motionContentProviderArray[0]);
                         } else {
-                            var motionCatalogContentProvider = MotionCatalogContentProvider.createInstance(motionContentProviderArray);
+                            var motionCatalogContentProvider = MotionCatalogContentProvider.createInstance(motionContentProviderArray, params.column);
                             documentProviderPromise = PdfMakeDocumentProvider.createInstance(motionCatalogContentProvider);
                         }
                         documentProviderPromise.then(function (documentProvider) {
@@ -1041,9 +1321,7 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
             },
             export: function (motions, params, singleMotion) {
                 params = params || {};
-                _.defaults(params, {
-                    filename: gettextCatalog.getString('motions') + '.pdf',
-                });
+                params.filename = gettextCatalog.getString('motions') + '.pdf';
                 this.getDocumentProvider(motions, params, singleMotion).then(
                     function (documentProvider) {
                         PdfCreate.download(documentProvider, params.filename);
@@ -1155,6 +1433,13 @@ angular.module('OpenSlidesApp.motions.pdf', ['OpenSlidesApp.core.pdf'])
                     });
                 }
             },
+            exportAmendments: function (motions, filename) {
+                AmendmentContentProvider.createInstance(motions).then(function (contentProvider) {
+                    PdfMakeDocumentProvider.createInstance(contentProvider).then(function (documentProvider) {
+                        PdfCreate.download(documentProvider, filename);
+                    });
+                });
+            },
         };
     }
 ]);
